package samples;

import javax.swing.*;
import java.awt.*;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import static java.lang.System.*;

/**
 * Using key events and a key listener
 * (Sadly we have an key delay, a bit technical to remove so we don't ...)
 */
public class BoundingBox extends JPanel {

    public static void main(String[] args) {
        new BoundingBox().program();
    }

    final int width = 400;
    final int height = 400;

    final Square s = new Square(100, 100, 20, 20);
    final Square fixed = new Square(150, 150, 50, 50);

    void program() {
        initGraphics();
    }

    public void paint(Graphics g) {
        super.paint(g);
        Graphics2D g2 = (Graphics2D) g;
        //g2.drawString("Use arrow keys to move me", 10, 10);

        g2.fillRect(150, height-150, 50, 50);
        g2.fillRect(100, height-100, 20, 20);


        g2.setColor(Color.CYAN);
        Rectangle r = s.getBoundingBox();
        g2.drawRect(r.x, height - r.y, r.width, r.height);
        r = fixed.getBoundingBox();
        g2.drawRect(r.x, height - r.y, r.width, r.height);

    }

    // Our method to handle pressed keys
    void handleKeys(int keyCode) {
        if (keyCode == KeyEvent.VK_UP) {
            s.y++;
        } else if (keyCode == KeyEvent.VK_DOWN) {
            s.y--;
        } else if (keyCode == KeyEvent.VK_LEFT) {
            s.x--;
        } else if (keyCode == KeyEvent.VK_RIGHT) {
            s.x++;
        }

        // Flip because must compare screen coordinates
        // Else the view of a collision will not be same be logical collision
        Rectangle r1 = s.getBoundingBox();
        Rectangle r2 = fixed.getBoundingBox();
        if (flipBoundingBox(r1).intersects(flipBoundingBox(r2))) {
            out.println("Intersect:" + s.y + ":" + (height - s.y));
        }
    }

    // Convert bounding box too screen coordinates
    Rectangle flipBoundingBox(Rectangle r) {
        r.y = height - r.y;
        return r;
    }

    void initGraphics() {
        setPreferredSize(new Dimension(width, height));
        JFrame window = new JFrame();
        window.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        window.add(this);
        window.pack();
        window.setLocationRelativeTo(null);
        window.setVisible(true);
        // Connect a key listener object to the window
        window.addKeyListener(new KeyAdapter() {
            public void keyPressed(KeyEvent e) {
                handleKeys(e.getKeyCode());
                repaint();
            }
        });
    }


    // --------- Trivial class -------------------

    class Square {
        double x;  // left x
        double y;   // top y
        double width;   // full width
        double height;  // full height

        Square(double x, double y, double width, double height) {
            this.x = x;
            this.y = y;
            this.width = width;
            this.height = height;
        }

        // Logical bounding box
        Rectangle getBoundingBox() {
            return new Rectangle((int) x, (int) y, (int) (width), (int) (this.height));
        }
    }


}






